@@ -1,7 +1,7 @@
 import sys, argparse
-from configManager import load_configs,get_variables
-from LambdaFunction import LambdaFunction
-from File import File
+from .configManager import load_configs,get_variables
+from .LambdaFunction import LambdaFunction
+from .File import File
 
 
 
